@@ -7,10 +7,10 @@ import MDAnalysis as mda_
 from MDAnalysis.lib.nsgrid import FastNS as FastNS_
 from MDAnalysis.lib.distances import calc_angles, calc_bonds
 import tqdm.auto as tqdm_
-from numba import njit_
+from numba import njit as _njit
 
 from .dihedral import OrderParameter
 from .entropy import eFingerprint
 
 # Version of the package
-__version__ = "1.0.2"
+__version__ = "1.0.3"
