@@ -183,7 +183,7 @@ class OrderParameter:
                 particle_counter += 1
             counter_list.append(particle_counter)
             f4_list.append(avg_f4/particle_counter)
-        self.F4 = f4_list
+        self.f4 = f4_list
         
     ############# orientational tetrahedral order parameter........
     def singleOTO(self, item, arr):
